==> eiffelstudio-18.11.10.2592.tar: F_code/C5/cl222.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl222.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F262_3645 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1128, 0x01).id, 1128, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1124_9589(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F262_3646 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	F262_3647(Current);
	Result = '\0';
	if (F262_3661(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F262_3647 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	F262_3665(Current);
	F262_3666(Current);
	F262_3648(Current);
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F262_3648 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		F262_3666(Current);
		F262_3649(Current);
	} else {
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F262_3649 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		F262_3666(Current);
		F262_3648(Current);
		F262_3650(Current);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F262_3650 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		F262_3666(Current);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			F262_3666(Current);
			F262_3648(Current);
			F262_3650(Current);
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.current_parsed_string */
EIF_REFERENCE F262_3659 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current);
}


/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F262_3661 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R8220[Dtype(tr1)-1126])(RTCW(tr1));
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F262_3664 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F262_3665 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F262_3661(Current)) {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R8184[Dtype(tr1)-1127])(RTCW(tr1), *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F262_3666 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F262_3664(Current);
			}
			if (tb1) break;
			F262_3665(Current);
		}
		if ((EIF_BOOLEAN) !F262_3664(Current)) {
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					F262_3665(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					F262_3665(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					F262_3665(Current);
					break;
				default:
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(1077, 0x00).id, 1077, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F1076_9422(RTCW(tr1));
					if (tb2) {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						tr1 = RTLNS(eif_new_type(1128, 0x01).id, 1128, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1127_9719(RTCW(tr1), ((EIF_INTEGER_32) 20L));
						loc1 = (EIF_REFERENCE) tr1;
						for (;;) {
							tb2 = '\01';
							if (!F262_3664(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(1077, 0x00).id, 1077, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F1076_9430(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							F1129_9846(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							F262_3665(Current);
						}
						tr1 = RTOUCR(529,F261_3633,(Current));
						tr2 = F1129_9866(RTCW(loc1));
						tb3 = F913_8091(RTCW(tr1), tr2);
						if (tb3) {
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTLE;
}

void EIF_Minit222 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C5/cl222.c <==
/*
 * Code for class CLASS_TYPE_NAME_SYNTAX_CHECKER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "cl222.h"
#include <ctype.h>

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.default_create */
void F257_3621 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	tr1 = RTLNS(eif_new_type(1129, 0x01).id, 1129, _OBJSIZ_1_1_0_3_0_0_0_0_);
	F1125_9612(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_valid_class_type_name */
EIF_BOOLEAN F257_3622 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLIU(2);
	
	RTGC;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) arg1;
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 1L);
	F257_3623(Current);
	Result = '\0';
	if (F257_3637(Current)) {
		Result = (EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 6L));
	}
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_start */
void F257_3623 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) 'S';
	*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	F257_3641(Current);
	F257_3642(Current);
	F257_3624(Current);
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type */
void F257_3624 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 2L))) {
		F257_3642(Current);
		F257_3625(Current);
	} else {
		*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_generics */
void F257_3625 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 3L))) {
		F257_3642(Current);
		F257_3624(Current);
		F257_3626(Current);
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_type_list */
void F257_3626 (EIF_REFERENCE Current)
{
	GTCX
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 4L))) {
		F257_3642(Current);
	} else {
		if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) == ((EIF_INTEGER_32) 5L))) {
			F257_3642(Current);
			F257_3624(Current);
			F257_3626(Current);
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
		}
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_end_of_input */
EIF_BOOLEAN F257_3637 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_);
	tr1 = *(EIF_REFERENCE *)(Current);
	ti4_2 = (FUNCTION_CAST(EIF_INTEGER_32, (EIF_REFERENCE)) R8240[Dtype(RTCW(tr1))-1128])(tr1);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN) (ti4_1 > ti4_2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.is_eof */
EIF_BOOLEAN F257_3640 (EIF_REFERENCE Current)
{
	GTCX
	EIF_CHARACTER_32 tw1;
	EIF_CHARACTER_32 tw2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTGC;
	tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
	tw2 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(tw1 == tw2);
	RTLE;
	return Result;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_character */
void F257_3641 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE tr1 = NULL;
	EIF_CHARACTER_32 tw1;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTGC;
	if (F257_3637(Current)) {
		tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '\000';
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
	} else {
		tr1 = *(EIF_REFERENCE *)(Current);
		tw1 = (FUNCTION_CAST(EIF_CHARACTER_32, (EIF_REFERENCE, EIF_INTEGER_32)) R8204[Dtype(RTCW(tr1))-1128])(tr1, *(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_));
		*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) = (EIF_CHARACTER_32) tw1;
		(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_1_))++;
	}
	RTLE;
}

/* {CLASS_TYPE_NAME_SYNTAX_CHECKER}.consume_current_token */
void F257_3642 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_CHARACTER_32 tw1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN tb3;
	EIF_BOOLEAN tb4;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,loc1);
	RTLR(3,tr2);
	RTLIU(4);
	
	RTGC;
	if ((EIF_BOOLEAN)(*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) != ((EIF_INTEGER_32) 7L))) {
		for (;;) {
			tb1 = '\01';
			tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
			tb2 = EIF_TEST(isspace(tw1));
			if (!(EIF_BOOLEAN) !tb2) {
				tb1 = F257_3640(Current);
			}
			if (tb1) break;
			F257_3641(Current);
		}
		if ((EIF_BOOLEAN) !F257_3640(Current)) {
			switch (*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_)) {
				case (EIF_CHARACTER_8) '[':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 3L);
					F257_3641(Current);
					break;
				case (EIF_CHARACTER_8) ']':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 4L);
					F257_3641(Current);
					break;
				case (EIF_CHARACTER_8) ',':
					*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 5L);
					F257_3641(Current);
					break;
				default:
					tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
					tr1 = RTLNS(eif_new_type(1078, 0x00).id, 1078, _OBJSIZ_0_0_0_1_0_0_0_0_);
					*(EIF_CHARACTER_32 *)tr1 = tw1;
					tb2 = F1077_9445(RTCW(tr1));
					if (tb2) {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 2L);
						loc1 = RTLNS(eif_new_type(1129, 0x01).id, 1129, _OBJSIZ_1_1_0_3_0_0_0_0_);
						F1128_9742(RTCW(loc1), ((EIF_INTEGER_32) 20L));
						for (;;) {
							tb2 = '\01';
							if (!F257_3640(Current)) {
								tb3 = '\01';
								tw1 = *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_);
								tr1 = RTLNS(eif_new_type(1078, 0x00).id, 1078, _OBJSIZ_0_0_0_1_0_0_0_0_);
								*(EIF_CHARACTER_32 *)tr1 = tw1;
								tb4 = F1077_9453(RTCW(tr1));
								if (!tb4) {
									tw1 = (EIF_CHARACTER_32) (EIF_CHARACTER_8) '_';
									tb3 = (EIF_BOOLEAN)(*(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_) == tw1);
								}
								tb2 = (EIF_BOOLEAN) !tb3;
							}
							if (tb2) break;
							F1130_9869(RTCW(loc1), *(EIF_CHARACTER_32 *)(Current+ _LNGOFF_1_0_0_0_));
							F257_3641(Current);
						}
						tr1 = RTOUCR(545,F256_3609, (Current));
						tr2 = F1130_9889(RTCW(loc1));
						tb3 = F914_8114(RTCW(tr1), tr2);
						if (tb3) {
							*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
						}
					} else {
						*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 7L);
					}
					break;
			}
		} else {
			*(EIF_INTEGER_32 *)(Current+ _LNGOFF_1_0_0_2_) = (EIF_INTEGER_32) ((EIF_INTEGER_32) 6L);
		}
	}
	RTLE;
}

void EIF_Minit222 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
